from __future__ import print_function, absolute_import, division


def get_item_from_module(module_name, item_name):
    """Load classes/modules/functions/... from given config"""
    try:
        module = __import__(module_name, fromlist=[item_name])
        item = getattr(module, item_name)
    except ImportError as error:
        message = 'Module "{modulename}" could not be loaded: {e}'
        raise Exception(message.format(
            modulename=module_name, e=error))
    except AttributeError as error:
        message = 'No item "{itemname}" in module "{modulename}": {e}'
        raise Exception(message.format(
            modulename=module_name,
            itemname=item_name,
                e=error))
    return item



#!/usr/bin/env python

from setuptools import setup

if __name__ == '__main__':
    setup(
          name = 'pils',
          version = '0.1.12-0',
          description = '''PILS - Python uTILS''',
          long_description = '''PILS is a container for utilis written in python''',
          author = "",
          author_email = "",
          license = 'Apache License 2.0',
          url = 'https://github.com/ImmobilienScout24/pils',
          scripts = [],
          packages = ['pils'],
          py_modules = [],
          classifiers = ['Development Status :: 3 - Alpha', 'Programming Language :: Python'],
          entry_points={
          'console_scripts':
              []
          },
             #  data files
             # package data
          
          
          zip_safe=True
    )
